@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogAny::NullLogging;
 
-our $VERSION = 0.08; # VERSION
+our $VERSION = 0.09; # VERSION
 
 our $results = [
   [
@@ -9,39 +9,39 @@ our $results = [
     [
       {
         env => "PERL5OPT=-Iarchive/Log-Any-1.041/lib",
-        errors => 0.00019,
+        errors => 0.00024,
         participant => "100k_log_trace",
-        rate => 15,
+        rate => 13,
         samples => 20,
-        time => 67,
+        time => 76,
         vs_slowest => 1,
       },
       {
         env => "PERL5OPT=-Iarchive/Log-Any-1.040/lib",
-        errors => 0.00029,
+        errors => 0.00018,
         participant => "100k_log_trace",
-        rate => 15,
-        samples => 21,
-        time => 66,
+        rate => 14,
+        samples => 20,
+        time => 72,
         vs_slowest => 1,
       },
       {
         env => "PERL5OPT=-Iarchive/Log-Any-1.041/lib",
         errors => 0.00015,
         participant => "100k_is_trace",
-        rate => 22,
+        rate => 18,
         samples => 20,
-        time => 45,
-        vs_slowest => 1.5,
+        time => 54,
+        vs_slowest => 1.4,
       },
       {
         env => "PERL5OPT=-Iarchive/Log-Any-1.040/lib",
-        errors => 0.00021,
+        errors => 0.00012,
         participant => "100k_is_trace",
-        rate => 23,
+        rate => 19,
         samples => 21,
-        time => 44,
-        vs_slowest => 1.5,
+        time => 53,
+        vs_slowest => 1.4,
       },
     ],
     {
@@ -93,7 +93,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -116,7 +115,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -124,20 +122,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -146,30 +140,16 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => "2758.820",
-                                              stepping                     => 4,
+                                              speed                        => 3200.023,
+                                              stepping                     => 7,
                                             },
                                             {
                                               address_width                => 64,
@@ -208,7 +188,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -231,7 +210,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -239,20 +217,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -261,30 +235,16 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => "2820.890",
-                                              stepping                     => 4,
+                                              speed                        => 3200.386,
+                                              stepping                     => 7,
                                             },
                                             {
                                               address_width                => 64,
@@ -323,7 +283,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -346,7 +305,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -354,20 +312,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -376,30 +330,16 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2635.281,
-                                              stepping                     => 4,
+                                              speed                        => 3200.144,
+                                              stepping                     => 7,
                                             },
                                             {
                                               address_width                => 64,
@@ -438,7 +378,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -461,7 +400,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -469,20 +407,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -491,64 +425,50 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => "2898.000",
-                                              stepping                     => 4,
+                                              speed                        => 3200.144,
+                                              stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 5.03511714935303,
+      "func.elapsed_time"              => 6.02018594741821,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
-                                            "__PACKAGE__" => 1.034,
+                                            "__PACKAGE__" => 1.039,
                                             "Bencher::Scenario::LogAny::NullLogging" => undef,
-                                            "Benchmark::Dumb" => "0.10",
+                                            "Benchmark::Dumb" => 0.111,
                                             "Devel::Platform::Info" => 0.16,
-                                            "perl" => "v5.24.0",
+                                            "perl" => "v5.26.0",
                                             "Sys::Info" => 0.78,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
       "func.permute"                   => ["perl", ["perl"], "participant", [0, 1], "env_hash", [0, 1]],
       "func.platform_info"             => {
                                             archname => "x86_64",
-                                            codename => "rosa",
+                                            codename => "jessie",
                                             is32bit  => 0,
                                             is64bit  => 1,
-                                            kernel   => "linux-3.19.0-32-generic",
+                                            kernel   => "linux-3.16.0-4-amd64",
                                             kname    => "Linux",
-                                            kvers    => "3.19.0-32-generic",
+                                            kvers    => "3.16.0-4-amd64",
                                             osflag   => "linux",
-                                            oslabel  => "LinuxMint",
+                                            oslabel  => "Debian",
                                             osname   => "GNU/Linux",
-                                            osvers   => 17.3,
+                                            osvers   => "8.0",
                                             source   => {
                                                           "cat /etc/.issue" => "",
-                                                          "cat /etc/issue"  => "Linux Mint 17.3 Rosa \\n \\l",
-                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 17.3 Rosa\nRelease:\t17.3\nCodename:\trosa",
-                                                          "uname -a"        => "Linux backpacker 3.19.0-32-generic #37~14.04.1-Ubuntu SMP Thu Oct 22 09:41:40 UTC 2015 x86_64 x86_64 x86_64 GNU/Linux",
+                                                          "cat /etc/issue"  => "Debian GNU/Linux 8 \\n \\l",
+                                                          "lsb_release -a"  => "Distributor ID:\tDebian\nDescription:\tDebian GNU/Linux 8.0 (jessie)\nRelease:\t8.0\nCodename:\tjessie",
+                                                          "uname -a"        => "Linux builder 3.16.0-4-amd64 #1 SMP Debian 3.16.36-1+deb8u2 (2016-10-19) x86_64 GNU/Linux",
                                                           "uname -m"        => "x86_64",
                                                           "uname -o"        => "GNU/Linux",
-                                                          "uname -r"        => "3.19.0-32-generic",
+                                                          "uname -r"        => "3.16.0-4-amd64",
                                                           "uname -s"        => "Linux",
                                                         },
                                           },
@@ -562,9 +482,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1471657511,
       "func.scenario_module_sha1sum"   => "7adbec11350f000693b3a9615c6f83644210ef86",
       "func.scenario_module_sha256sum" => "1504d013899b8c9d181df19cc922e0d4a316a18f8be5be05cfdd15cb9886f2bd",
-      "func.time_end"                  => 1485330991.82248,
+      "func.time_end"                  => 1499688200.26553,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1485330986.78737,
+      "func.time_start"                => 1499688194.24535,
       "table.field_aligns"             => [
                                             "left",
                                             "left",
