@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogAny::Startup;
 
-our $VERSION = 0.08; # VERSION
+our $VERSION = 0.09; # VERSION
 
 our $results = [
   [
@@ -8,148 +8,136 @@ our $results = [
     "OK",
     [
       {
-        errors => 6.5e-05,
-        mod_overhead_time => 14.1,
+        errors => 6.1e-05,
+        mod_overhead_time => 15.1,
         modver => 1.032,
         participant => "Log::Any",
-        proc_private_dirty_size => 1.4,
-        proc_rss_size => 4.8,
-        proc_size => 17,
-        samples => 21,
-        time => 16,
+        proc_private_dirty_size => 1.6,
+        proc_rss_size => 5,
+        proc_size => 21,
+        samples => 20,
+        time => 17,
         vs_slowest => 1,
       },
       {
-        errors => 3.1e-05,
-        mod_overhead_time => 9.1,
+        errors => 2.7e-05,
+        mod_overhead_time => 11.1,
         modver => "",
         participant => "Log::Any::Adapter::Screen",
-        proc_private_dirty_size => 1.4,
-        proc_rss_size => 4.7,
-        proc_size => 17,
+        proc_private_dirty_size => 1.6,
+        proc_rss_size => 5,
+        proc_size => 21,
+        samples => 20,
+        time => 13,
+        vs_slowest => 1.3,
+      },
+      {
+        errors => 4.9e-05,
+        mod_overhead_time => 10.1,
+        modver => "",
+        participant => "Log::Any::Adapter::Stdout",
+        proc_private_dirty_size => 1.5,
+        proc_rss_size => 5,
+        proc_size => 21,
+        samples => 20,
+        time => 12,
+        vs_slowest => 1.4,
+      },
+      {
+        errors => 3.7e-05,
+        mod_overhead_time => 10.1,
+        modver => "",
+        participant => "Log::Any::Adapter::Null",
+        proc_private_dirty_size => 1.7,
+        proc_rss_size => 5.2,
+        proc_size => 21,
+        samples => 20,
+        time => 12,
+        vs_slowest => 1.4,
+      },
+      {
+        errors => 6.4e-05,
+        mod_overhead_time => 9.1,
+        modver => 1.049,
+        participant => "Log::Any",
+        proc_private_dirty_size => 1.6,
+        proc_rss_size => 5.1,
+        proc_size => 21,
         samples => 20,
         time => 11,
         vs_slowest => 1.5,
       },
       {
-        errors => 5.2e-05,
-        mod_overhead_time => 7.9,
-        modver => "",
-        participant => "Log::Any::Adapter::Stdout",
-        proc_private_dirty_size => 0.86,
-        proc_rss_size => 4.1,
-        proc_size => 16,
-        samples => 21,
-        time => 9.8,
-        vs_slowest => 1.6,
-      },
-      {
-        errors => 1.6e-05,
-        mod_overhead_time => 7.5,
-        modver => "",
-        participant => "Log::Any::Adapter::Null",
-        proc_private_dirty_size => 1.6,
-        proc_rss_size => 5,
-        proc_size => 17,
-        samples => 22,
-        time => 9.4,
-        vs_slowest => 1.7,
-      },
-      {
-        errors => 4.5e-05,
-        mod_overhead_time => 7,
+        errors => 4.1e-05,
+        mod_overhead_time => 9.1,
         modver => "",
         participant => "Log::Any::Proxy",
-        proc_private_dirty_size => 0.82,
-        proc_rss_size => 4.1,
-        proc_size => 16,
+        proc_private_dirty_size => 0.83,
+        proc_rss_size => 4.2,
+        proc_size => 20,
         samples => 20,
-        time => 8.9,
-        vs_slowest => 1.8,
+        time => 11,
+        vs_slowest => 1.5,
       },
       {
-        errors => 5.2e-05,
-        mod_overhead_time => 6.9,
+        errors => 3.4e-05,
+        mod_overhead_time => 7.6,
         modver => 1.041,
         participant => "Log::Any",
-        proc_private_dirty_size => 1.4,
-        proc_rss_size => 4.9,
-        proc_size => 17,
+        proc_private_dirty_size => 1.6,
+        proc_rss_size => 5.1,
+        proc_size => 21,
         samples => 20,
-        time => 8.8,
+        time => 9.5,
         vs_slowest => 1.8,
       },
       {
         errors => 4.7e-05,
-        mod_overhead_time => 6.9,
-        modver => 1.042,
+        mod_overhead_time => 6.4,
+        modver => "1.040",
         participant => "Log::Any",
-        proc_private_dirty_size => 1.4,
-        proc_rss_size => 4.7,
-        proc_size => 17,
+        proc_private_dirty_size => 1.6,
+        proc_rss_size => 5,
+        proc_size => 21,
         samples => 20,
-        time => 8.8,
-        vs_slowest => 1.8,
-      },
-      {
-        errors => 3.3e-05,
-        mod_overhead_time => 5.8,
-        modver => 1.038,
-        participant => "Log::Any",
-        proc_private_dirty_size => 1.4,
-        proc_rss_size => 4.8,
-        proc_size => 17,
-        samples => 20,
-        time => 7.7,
+        time => 8.3,
         vs_slowest => 2,
       },
       {
-        errors => 4.3e-05,
-        mod_overhead_time => 5.8,
-        modver => "1.040",
+        errors => 3.3e-05,
+        mod_overhead_time => 6.2,
+        modver => 1.038,
         participant => "Log::Any",
-        proc_private_dirty_size => 1.5,
-        proc_rss_size => 4.7,
-        proc_size => 17,
+        proc_private_dirty_size => 1.6,
+        proc_rss_size => 5,
+        proc_size => 21,
         samples => 20,
-        time => 7.7,
-        vs_slowest => 2.1,
-      },
-      {
-        errors => 2.7e-05,
-        mod_overhead_time => 2.8,
-        modver => 0.15,
-        participant => "Log::Any",
-        proc_private_dirty_size => 1.5,
-        proc_rss_size => 4.8,
-        proc_size => 17,
-        samples => 20,
-        time => 4.7,
-        vs_slowest => 3.3,
-      },
-      {
-        errors => 5.5e-06,
-        mod_overhead_time => 0.4,
-        modver => "",
-        participant => "Log::Any::IfLOG",
-        proc_private_dirty_size => 1.4,
-        proc_rss_size => 4.7,
-        proc_size => 17,
-        samples => 20,
-        time => 2.3,
-        vs_slowest => 6.7,
+        time => 8.1,
+        vs_slowest => 2,
       },
       {
         errors => 1.2e-05,
+        mod_overhead_time => 3,
+        modver => 0.15,
+        participant => "Log::Any",
+        proc_private_dirty_size => 1.6,
+        proc_rss_size => 5,
+        proc_size => 21,
+        samples => 20,
+        time => 4.9,
+        vs_slowest => 3.4,
+      },
+      {
+        errors => 1.6e-05,
         mod_overhead_time => 0,
         modver => "",
         participant => "perl -e1 (baseline)",
-        proc_private_dirty_size => 1.4,
-        proc_rss_size => 4.7,
-        proc_size => 17,
+        proc_private_dirty_size => 1.5,
+        proc_rss_size => 5,
+        proc_size => 21,
         samples => 20,
         time => 1.9,
-        vs_slowest => 8.4,
+        vs_slowest => 9,
       },
     ],
     {
@@ -205,7 +193,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -228,7 +215,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -236,20 +222,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -258,30 +240,16 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2712.664,
-                                              stepping                     => 4,
+                                              speed                        => 3200.023,
+                                              stepping                     => 7,
                                             },
                                             {
                                               address_width                => 64,
@@ -320,7 +288,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -343,7 +310,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -351,20 +317,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -373,30 +335,16 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2814.273,
-                                              stepping                     => 4,
+                                              speed                        => 3200.144,
+                                              stepping                     => 7,
                                             },
                                             {
                                               address_width                => 64,
@@ -435,7 +383,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -458,7 +405,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -466,20 +412,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -488,30 +430,16 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2614.007,
-                                              stepping                     => 4,
+                                              speed                        => 3200.023,
+                                              stepping                     => 7,
                                             },
                                             {
                                               address_width                => 64,
@@ -550,7 +478,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -573,7 +500,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -581,20 +507,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -603,87 +525,72 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2878.476,
-                                              stepping                     => 4,
+                                              speed                        => 3200.144,
+                                              stepping                     => 7,
                                             },
                                           ],
       "func.module_startup"            => 1,
       "func.module_versions"           => {
-                                            "__PACKAGE__"                        => 1.034,
+                                            "__PACKAGE__" => 1.039,
                                             "Bencher::Scenario::LogAny::Startup" => undef,
-                                            "Benchmark::Dumb"                    => "0.10",
-                                            "Devel::Platform::Info"              => 0.16,
-                                            "Log::Any"                           => 1.042,
-                                            "Log::Any::Adapter::Null"            => 1.042,
-                                            "Log::Any::Adapter::Screen"          => 0.13,
-                                            "Log::Any::Adapter::Stdout"          => 1.042,
-                                            "Log::Any::IfLOG"                    => 0.08,
-                                            "Log::Any::Proxy"                    => 1.042,
-                                            "perl"                               => "v5.24.0",
-                                            "Sys::Info"                          => 0.78,
+                                            "Benchmark::Dumb" => 0.111,
+                                            "Devel::Platform::Info" => 0.16,
+                                            "Log::Any" => 1.049,
+                                            "Log::Any::Adapter::Null" => 1.049,
+                                            "Log::Any::Adapter::Screen" => 0.13,
+                                            "Log::Any::Adapter::Stdout" => 1.049,
+                                            "Log::Any::Proxy" => 1.049,
+                                            "perl" => "v5.26.0",
+                                            "Sys::Info" => 0.78,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
       "func.permute"                   => [
                                             "perl",
                                             ["perl"],
                                             "modver",
-                                            [1.032, 0.15, 1.042, "1.040", 1.038, 1.041],
+                                            [1.049, 0.15, "1.040", 1.041, 1.038, 1.032],
                                             "participant",
-                                            [0 .. 6],
+                                            [0 .. 5],
                                           ],
       "func.platform_info"             => {
                                             archname => "x86_64",
-                                            codename => "rosa",
+                                            codename => "jessie",
                                             is32bit  => 0,
                                             is64bit  => 1,
-                                            kernel   => "linux-3.19.0-32-generic",
+                                            kernel   => "linux-3.16.0-4-amd64",
                                             kname    => "Linux",
-                                            kvers    => "3.19.0-32-generic",
+                                            kvers    => "3.16.0-4-amd64",
                                             osflag   => "linux",
-                                            oslabel  => "LinuxMint",
+                                            oslabel  => "Debian",
                                             osname   => "GNU/Linux",
-                                            osvers   => 17.3,
+                                            osvers   => "8.0",
                                             source   => {
                                                           "cat /etc/.issue" => "",
-                                                          "cat /etc/issue"  => "Linux Mint 17.3 Rosa \\n \\l",
-                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 17.3 Rosa\nRelease:\t17.3\nCodename:\trosa",
-                                                          "uname -a"        => "Linux backpacker 3.19.0-32-generic #37~14.04.1-Ubuntu SMP Thu Oct 22 09:41:40 UTC 2015 x86_64 x86_64 x86_64 GNU/Linux",
+                                                          "cat /etc/issue"  => "Debian GNU/Linux 8 \\n \\l",
+                                                          "lsb_release -a"  => "Distributor ID:\tDebian\nDescription:\tDebian GNU/Linux 8.0 (jessie)\nRelease:\t8.0\nCodename:\tjessie",
+                                                          "uname -a"        => "Linux builder 3.16.0-4-amd64 #1 SMP Debian 3.16.36-1+deb8u2 (2016-10-19) x86_64 GNU/Linux",
                                                           "uname -m"        => "x86_64",
                                                           "uname -o"        => "GNU/Linux",
-                                                          "uname -r"        => "3.19.0-32-generic",
+                                                          "uname -r"        => "3.16.0-4-amd64",
                                                           "uname -s"        => "Linux",
                                                         },
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::LogAny::Startup",
-      "func.scenario_module_md5sum"    => "cbaefaddb06b7c8fbe5b95f89cd94589",
-      "func.scenario_module_mtime"     => 1453223152,
-      "func.scenario_module_sha1sum"   => "585ee1a59f31765747bc92d2bb89fa100efb9057",
-      "func.scenario_module_sha256sum" => "f0d5a3fa00796147e31cc3c5a899e18f41b65a63efd2529d1c96db94db980a73",
+      "func.scenario_module_md5sum"    => "66a1165ffed5b3d5abff344b8e9a7ef2",
+      "func.scenario_module_mtime"     => 1499688113,
+      "func.scenario_module_sha1sum"   => "6f9d1c329de4061277b510135a8b4984e6e84c15",
+      "func.scenario_module_sha256sum" => "88f9e0bea91e5436267d31d041108b74c6ec3f03bd8609c1212ac6edfcbd56e0",
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1485330992.00376,
+      "func.time_start"                => 1499688200.46338,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "ms", "ms"],
       "table.fields"                   => [
